<%@ page language="java" contentType="text/html; charset=UTF-8"
    pageEncoding="UTF-8"%>
<%@ taglib prefix="tag" tagdir="/WEB-INF/tags" %>
<%@taglib prefix="c" uri="http://java.sun.com/jsp/jstl/core" %>
<%@taglib prefix="fn" uri="http://java.sun.com/jsp/jstl/functions" %>
<c:set var="req" value="${pageContext.request}" />
<c:set var="url">${req.requestURL}</c:set>
<c:set var="base" value="${fn:substring(url, 0, fn:length(url) - fn:length(req.requestURI))}${req.contextPath}/" />

<!DOCTYPE html>
<html>

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0" />
    <link type="text/css" rel="stylesheet" href="../css/material-icons.css" />
    <link type="text/css" rel="stylesheet" href="../css/materialize.min.css" media="screen,projection" />
    <link type="text/css" rel="stylesheet" href="../css/style.min.css" media="screen,projection" />
    <link rel="icon" href="../img/favicon.ico" />
    <title>Scan - Microfolie Lens</title>
</head>

<body class="grey lighten-3">
    <!-- Header -->
    <header class="navbar-fixed">
        <nav class="red">
            <div class="nav-wrapper">
                <span class="brand-logo center mtop-half hide-on-med-and-down"><img src="../img/logo.png"
                        title="Logo Microfolie" class="responsive-img" style="max-width: 128px;" /></span>
                <span class="brand-logo center hide-on-large-only">Microfolie Lens</span>
                <div class="left mleft-2 hide-on-med-and-down">
                    <span>
                        <h5>Microfolie Lens</h5>
                    </span>
                </div>
            </div>
        </nav>
    </header>
    <div class="mtop-5 hide-on-med-and-down"></div>

    <!-- Main -->
    <main class="container">
        <div class="row">
            <div class="col s12 center-align">
                <h3 id="title">QR Code Scanner</h3>
            </div>
        </div>
        <div class="row">
            <div class="col s12 center-align">
                <video id="qr-preview"></video>
            </div>
        </div>
    </main>

    <!-- Popup -->
    <div id="ok-popup" class="modal popup">
        <div class="modal-content" style="overflow: hidden;">
            <div class="row">
                <div class="col offset-m1 m3 s12">
                    <i class="material-icons green-text" style="font-size: 8em;">check_circle</i>
                </div>
                <div class="col m7 s12 mtop-3">
                    <h4 id="ok-text">Success message</h4>
                </div>
            </div>    
        </div>
    </div>
    <div id="err-popup" class="modal popup">
        <div class="modal-content" style="overflow: hidden;">
            <div class="row">
                <div class="col offset-m1 m3 s12">
                    <i class="material-icons red-text" style="font-size: 8em;">error</i>
                </div>
                <div class="col m7 s12 mtop-3">
                    <h4 id="error-text">Error message</h4>
                </div>
            </div>    
        </div>
    </div>
    <!--  Loader  -->
    <tag:loader name="loader" />

    <!-- Script -->
    <script type="text/javascript" src="../js/jquery.min.js"></script>
    <script type="text/javascript" src="../js/materialize.min.js"></script>
    <script type="text/javascript" src="../js/script.js"></script>
    <!-- Script pour cette page-->
    <script type="text/javascript" src="../js/instascan.min.js"></script>
    <script type="text/javascript">
    	$(document).ready(() => {
    		const okPopup = M.Modal.getInstance($('#ok-popup'));
    		const errPopup = M.Modal.getInstance($('#err-popup'));
    		const loader = M.Modal.getInstance($('#loader'));
    		
    		// Lecteur cookie espace
            const espace = getCookie("microfolies.lens.espace");
    		// Si pas de cookie retour sur la page d'accueil
            if (espace === undefined) {
                window.location.href = "${base}";
            }
    		
    		// Recupération du nom reel de l'espace pour le titre
    		loader.open();
    		$.ajax({
                type: "GET",
                url: "${base}api/espace/get/" + espace,
                error: () => {
                	loader.close();
                	$('#title').html(espace.capitalize());
                },
                success: (result) => {
                	loader.close();
                	$('#title').html(result.data.libelle.capitalize());
                },
            });
            
            //Scanner QRcode
            const scanner = new Instascan.Scanner({ video: document.getElementById('qr-preview') });
            scanner.addListener('scan', function (content) {
            	loader.open();
                const result = espace ? espace + "/" + content : content;
                $.ajax({
                	type: "POST",
                	url: "${base}api/badge/" + result,
                	error: () => {
                		$("#error-text").html('Une erreur est survenue');
                		loader.close();
                		errPopup.open();
                	},
                	success: (result) => {
                		loader.close();
                		if (result.success) {
                			$("#ok-text").html(result.data.msg);
                			okPopup.open();
                		} else {
                			$("#error-text").html(result.data);
                			errPopup.open();
                		}
                	},
                });
            });
            Instascan.Camera.getCameras().then(function (cameras) {
                if (cameras.length > 0) {
                    scanner.start(cameras[0]);
                }
                else {
                    console.error('No cameras found.');
                }
            }).catch(err => {
                console.error(err);
            });	
    	});
    </script>
</body>

</html>